@@ -1349,7 +1349,7 @@ class LaharFlowData(object):
         return val
     
     def POI_buffer(self,  lon, lat, buffer, data=None, filename=None, var=None,
-                   full_domain=False, nodata=np.nan, fill_value=0, interp_method='linear',
+                   full_domain=False, nodata=np.nan, 
                    name='POI'):
         
         if data is None and filename is None:
@@ -1370,7 +1370,16 @@ class LaharFlowData(object):
 
         indx = np.sqrt((data['x_distance']-POI_xy[0])**2+(data['y_distance']-POI_xy[1])**2)<buffer
         
-        data_clipped = data[var][indx]
+        dt = [
+            ('x_distance', np.float64),
+            ('y_distance', np.float64),
+            ('latitude', np.float64),
+            ('longitude', np.float64),
+            (var, np.float64)]
+
+        data_clipped = np.full((len(indx),), np.nan, dtype=dt)
+
+        data_clipped[var] = data[var][indx]
         data_clipped['x_distance'] = data['x_distance'][indx]
         data_clipped['y_distance'] = data['y_distance'][indx]
         data_clipped['latitude'] = data['latitude'][indx]
